@@ -79,8 +79,18 @@ class CommunicationThread (threading.Thread):
     def webApi(self):
         while True:
             image=self.qForCom.get()
+            print('in communication',image)
             if image == CLOSE_NOW:
+                self.qForCom.task_done()
                 break;
+
+            if not main_paras.isWifiOk():
+                print('wifi problem')
+                #main_paras.guiNotify(CHECK_NETWORK_INDEX)
+                main_paras.api_result_que.put(None)
+                self.qForCom.task_done()
+                continue;
+            
             if type(image) ==list:
                 print(image)
                 if image[0] == SIGN_IN:    #[SIGN_IN, user, password]
