@@ -25,7 +25,9 @@ I2C_PORT                  =TOTAL_SLOTS
 #regular slot index is from 0 to TOTAL_SLOTS-1
 NON_SLOT_INDEX            =TOTAL_SLOTS
 SIGN_IN_FIRST_INDEX       = (NON_SLOT_INDEX+1)
-LANGUAGE_CHANGE_INDEX       = (NON_SLOT_INDEX+2)
+CHECK_NETWORK_INDEX       = (NON_SLOT_INDEX+2)
+LANGUAGE_CHANGE_INDEX     = (NON_SLOT_INDEX+3)
+WIFI_CHECKING_INDEX       = (NON_SLOT_INDEX+4)
 
 
 RESPONSE_SUCCESS   ='1'
