@@ -22,6 +22,7 @@ from profile_folder.profile_wrap import _ProfileDialog
 from help_folder.help_wrap import  _HelpDialog
 from setting_folder.setting_wrap import _SettingDialog
 from wifi_folder.wifi_list import _WifiList
+from wifi_folder import wifi_setting
 from volume.volume import _Volume
 from define import *
 from main_paras import setMainTopLeft, getMainTopLeft, mainChannelStart, setDetectionMode, getDetectionMode, setTestMode, getTestMode, queueForGui
@@ -74,6 +75,11 @@ class MainWindow(QtWidgets.QMainWindow):
         loadUi(os.path.join(currentPath,'spotii.ui'),self)
         self.tempPolling = QtCore.QTimer()
         self.tempPolling.timeout.connect(self.tempMonitor)
+        self.time = QtCore.QTimer()
+        self.time.timeout.connect(self.showTime)
+
+        self.currentWifi = '__lp_ls2_nothing__'
+
         self.page=0
         self.slots = []
         self.allIcons = []
@@ -83,6 +89,8 @@ class MainWindow(QtWidgets.QMainWindow):
         
         
     def tempMonitor(self):
+
+        self.wifiChecking()
         if sys.platform == 'linux':
             try:
                 result=subprocess.check_output(['vcgencmd','measure_temp']).decode("utf-8")
@@ -97,6 +105,22 @@ class MainWindow(QtWidgets.QMainWindow):
             except Exception as error:
                 print(error)
                 
+    def showTime(self):
+        try:
+            
+##            # getting current time
+##            current_time = QtCore.QTime.currentTime()
+##      
+##            # converting QTime object to string
+##            label_time = current_time.toString('hh:mm')
+
+            label_time = time.strftime('%H:%M')
+      
+            # showing it to the label
+            self.time_label.setText(label_time)
+            
+        except Exception as error:
+            print(error)
         
         
     def config(self):
@@ -117,24 +141,46 @@ class MainWindow(QtWidgets.QMainWindow):
 
             
             self.test_mode.clicked.connect(self.test_mode_hook)
+            
+            self.test_mode.setText(self.tr('NORMAL'))
+
 
             #self.help.clicked.connect(self.helpHookForTest)
             
             mainChannelStart(self.mainChannelHook)
             #self.chip_mode.setText(self.tr(getDetectionMode()))
             QtCore.QTimer.singleShot(0, self.setupAferUi)
-            
+
+            self.wifiChecking()
+            self.time.start(1000)
             self.tempPolling.start(10000)
-
-
             
             
         except Exception as error:
             print(error)
+
+    def wifiChecking(self):
+        wifi_ssid = wifi_setting.wifiSsid()
+        #print('ssid: ',wifi_ssid)
+        if  self.currentWifi != wifi_ssid:
+            icon = QtGui.QIcon()
+            if wifi_ssid == None:
+                main_paras.setWifiStatus(False)
+                print('set to invalid')
+                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-invalid.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
+                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-invalid.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
+            else:
+                main_paras.setWifiStatus(True)
+                print('set to normal')
+                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
+                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
+            self.wifi.setIcon(icon)
+            self.wifi.repaint()
+            self.currentWifi = wifi_ssid
         
     def test_mode_hook(self):
         try:
-            if self.test_mode.isChecked():
+            if not self.test_mode.isChecked():
                 self.test_mode.setText(self.tr('NORMAL'))
                 setTestMode(TEST_MODE_NORMAL)
             else:
@@ -204,19 +250,31 @@ class MainWindow(QtWidgets.QMainWindow):
             slotNo  = item[0]
             errCode = item[1]
             qrCode  = item[2]
-            
+            global popUp
             if slotNo == SIGN_IN_FIRST_INDEX:
-                global popUp
+                
                 popUp = _WrongPassword()
                 popUp.setMessage(self.tr("Sign in and enter basic test information."),self.tr('Ok'))
                 x,y = getMainTopLeft()
                 popUp.move(x,y)
                 popUp.show()
 
+##            elif slotNo == CHECK_NETWORK_INDEX:
+##                
+##                popUp = _WrongPassword()
+##                popUp.setMessage(self.tr("Check network."),self.tr('Try again'))
+##                x,y = getMainTopLeft()
+##                popUp.move(x,y)
+##                popUp.show()
+
             elif slotNo == LANGUAGE_CHANGE_INDEX:
                 print('LANGUAGE_CHANGE_INDEX')
                 self.language_change()
                 
+            elif slotNo == WIFI_CHECKING_INDEX:
+                print('WIFI_CHECKING_INDEX')
+                self.wifiChecking()
+                
             elif slotNo == NON_SLOT_INDEX:
                 for i in range(TOTAL_SLOTS):
                     self.slots[i].setStatus(SLOT_STATUS_WARNING, 'CR Error')
