@@ -71,6 +71,18 @@ class TimerThread(FunctionThread):
             
             self.emitThread.signal_to_Gui.emit(1)
         print('TimerThread done')
+def pre_install():
+    try:
+        upgrade=subprocess.check_output(['pip3','show','pytz','--disable-pip-version-check']).decode("utf-8")
+        print(upgrade)
+    except Exception as e:
+        print('pytz show exception: ',e)
+        try:
+            upgrade=subprocess.check_output(['pip3','install','pytz','--disable-pip-version-check']).decode("utf-8")
+            print(upgrade)
+        except Exception as e:
+            print('pytz install exception:',e)
+    
 class JobThread(FunctionThread):
     def __init__(self, emitThread):
         super(JobThread, self).__init__(emitThread)
@@ -84,13 +96,14 @@ class JobThread(FunctionThread):
             upgrade ='Nothing'
             try:
 #                upgrade=subprocess.check_output(['sudo','pip3','install','spotii','-U']).decode("utf-8")
-                upgrade=subprocess.check_output(['pip3','install','spotii','-U']).decode("utf-8")
+                upgrade=subprocess.check_output(['pip3','install','spotii','-U', '--disable-pip-version-check']).decode("utf-8")
             except subprocess.CalledProcessError as e:
                 print('subprocess error',e.output)
             except ConnectionError as e:
                 print('connection error',e)
             except Exception as e:
                 print('Exception',e)
+            #pre_install()
             #time.sleep(10)
             #print('upgrade:',upgrade)
 #             self.emitThread.signal_to_Gui.emit([upgrade,TASK_ONE_MILESTONE])
@@ -156,14 +169,16 @@ class MyUi(_Launcher):
 
 if __name__ == "__main__":
     import sys
-    emitThread=NotifyThread()
+    __emitThread=NotifyThread()
     app = QtWidgets.QApplication(sys.argv)
-    MainWindow = MyUi(emitThread) ##QtWidgets.QMainWindow()
+    MainWindow = MyUi(__emitThread) ##QtWidgets.QMainWindow()
     
     MainWindow.show()
     returnValue =app.exec_()
     print('launcher return value :' ,returnValue)
     initialized = MainWindow.status()
+    
+    
     if returnValue == 0 and initialized:
         
         #MainWindow.close()
