@@ -17,6 +17,8 @@ queueForCom     = queue.Queue()
 queueForResult  = queue.Queue()
 queueForOffLine = queue.Queue()
 
+def guiNotify(item):
+    queueForGui.put([item,'','',''])
 
 TITLE_HIGH = 48
 MAIN_X = 0
@@ -86,8 +88,8 @@ def setDetectionMode(mode):
 def getDetectionMode():
     return decMode
 
-test_mode = 'speed'
-testMode = TEST_MODE_SPEED
+test_mode = 'normal'
+testMode = TEST_MODE_NORMAL
 def setTestMode(mode):
     global testMode
     global test_mode
@@ -103,8 +105,8 @@ def getTestMode():
 def setAllDefault():
     global decMode,test_mode,testMode,manual_operation
     decMode = CASSETTE_DETECTION_MODE_AUTO #for different cassette identify mode base on cassette type
-    test_mode = 'speed'
-    testMode = TEST_MODE_SPEED
+    test_mode = 'normal'
+    testMode = TEST_MODE_NORMAL
     manual_operation = [MANUAL_OPERATION_START,MANUAL_OPERATION_START,MANUAL_OPERATION_START,MANUAL_OPERATION_START,MANUAL_OPERATION_START]# for manual command setting sequence
     
 sign_in_user =''
@@ -156,4 +158,11 @@ def setOffLineMode(mode):
     global off_line_mode
     off_line_mode = mode
 
+wifi_ok = True
+def isWifiOk():
+    return wifi_ok
+def setWifiStatus(status):
+    global wifi_ok
+    wifi_ok = status
+
 
